%define pypi_name ipyparallel

%bcond_with docs

Name:           ipyparallel
Version:        9.0.1
Release:        %mkrel 3
Group:          Development/Python
Summary:        Interactive Parallel Computing with IPython (tools)

License:        BSD
URL:            https://ipython.org/
Source0:        https://pypi.io/packages/source/i/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(pyzmq)
BuildRequires:  python3dist(traitlets)
BuildRequires:  python3dist(ipython-genutils)
BuildRequires:  python3dist(decorator)
BuildRequires:  python3dist(jupyter-client)
BuildRequires:  python3dist(ipykernel)
BuildRequires:  python3dist(tornado)
BuildRequires:  python3dist(pexpect)
BuildRequires:  python3dist(pickleshare)
BuildRequires:  python3dist(prompt-toolkit)
BuildRequires:  python3dist(simplegeneric)
BuildRequires:  python3dist(backcall)
# for docs
%if %{with docs}
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(intersphinx-registry)
BuildRequires:  python3dist(sphinxext-rediraffe)
BuildRequires:  python3dist(myst-nb)
# Not yet packaged
#BuildRequires:  python3-autodoc-traits
%endif

Requires:       python3-%{name} = %{version}-%{release}
Recommends:     %{name}-doc

%description
Use multiple instances of IPython in parallel, interactively.

This package installs the ipyparallel tools.

%package -n     python3-%{name}
Group:          Development/Python
Summary:        Interactive Parallel Computing with IPython (Python 3)
Recommends:     python3dist(mpi4py)
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
Use multiple instances of IPython in parallel, interactively.

This package installs the library for Python 3.

%package doc
Summary:       Interactive Parallel Computing with IPython documentation
Group:         Development/Python

%description doc
Use multiple instances of IPython in parallel, interactively.

This package contains examples of usage.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%if %{with docs}
pushd docs
PYTHONPATH=.. make html man SPHINXBUILD=sphinx-build-3
rm -f build/html/.buildinfo
popd
%endif

%install
%pyproject_install

# Install man page
%if %{with docs}
install -Dpm644 ./docs/build/man/ipythonparallel.1 %{buildroot}%{_mandir}/man1/ipythonparallel.1
%endif

# Fix wrong install directory for configuraton files
mv %{buildroot}%{_prefix}%{_sysconfdir} %{buildroot}%{_sysconfdir}

# python shebang
%py3_shebang_fix %{buildroot}%{python3_sitelib}/ipyparallel/*

%files
%{_bindir}/ipcluster
%{_bindir}/ipcontroller
%{_bindir}/ipengine

%files doc
%doc docs/source/examples
%if %{with docs}
%doc docs/build/html
%endif

%files -n python3-%{name}
%license COPYING.md
%if %{with docs}
%{_mandir}/man1/*
%endif
%{python3_sitelib}/ipyparallel/
%{python3_sitelib}/ipyparallel-%{version}.dist-info/
%{_datadir}/jupyter/labextensions/ipyparallel-labextension/
%{_datadir}/jupyter/nbextensions/ipyparallel/
%config(noreplace) %{_sysconfdir}/jupyter/jupyter_notebook_config.d/ipyparallel.json
%config(noreplace) %{_sysconfdir}/jupyter/jupyter_server_config.d/ipyparallel.json
%config(noreplace) %{_sysconfdir}/jupyter/nbconfig/tree.d/ipyparallel.json


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 9.0.1-3.mga10
+ Revision: 2242676
- Mageia 10 Mass Rebuild

* Tue Mar 04 2025 wally <wally> 9.0.1-2.mga10
+ Revision: 2160374
- rebuild for python3.13

* Mon Mar 03 2025 daviddavid <daviddavid> 9.0.1-1.mga10
+ Revision: 2159599
- new version: 9.0.1
- rebuild for python 3.13

* Fri Dec 29 2023 joequant <joequant> 6.3.0-4.mga10
+ Revision: 2023631
- update to py3.12

* Sun Apr 03 2022 umeabot <umeabot> 6.3.0-3.mga9
+ Revision: 1841226
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 6.3.0-2.mga9
+ Revision: 1787341
- rebuild for python-3.10

* Sun Apr 18 2021 daviddavid <daviddavid> 6.3.0-1.mga9
+ Revision: 1716596
- new version: 6.3.0

* Sat Mar 27 2021 daviddavid <daviddavid> 6.2.5-2.mga9
+ Revision: 1710952
- rebuild for python 3.9
- fix owner of python3 sitelib dir

* Thu Apr 30 2020 joequant <joequant> 6.2.5-1.mga8
+ Revision: 1573512
- update to 6.2.5

* Tue Feb 18 2020 umeabot <umeabot> 6.2.4-2.mga8
+ Revision: 1538574
- Mageia 8 Mass Rebuild

* Sat Nov 23 2019 daviddavid <daviddavid> 6.2.4-1.mga8
+ Revision: 1462326
- new version: 6.2.4

* Thu Sep 19 2019 daviddavid <daviddavid> 6.2.3-2.mga8
+ Revision: 1443760
- rebuild for python3.8

* Mon Jan 07 2019 wally <wally> 6.2.3-1.mga7
+ Revision: 1351149
- new version 6.2.3

* Thu Sep 20 2018 umeabot <umeabot> 6.0.2-2.mga7
+ Revision: 1278879
- Mageia 7 Mass Rebuild

* Tue Aug 08 2017 philippem <philippem> 6.0.2-1.mga7
+ Revision: 1139031
- update to 6.0.2, since ipython is py3 only, we provide only py3

* Sat Aug 05 2017 pterjan <pterjan> 5.0.1-3.mga7
+ Revision: 1135228
- Rebuild for python 3.6

* Wed Apr 20 2016 philippem <philippem> 5.0.1-2.mga6
+ Revision: 1003866
- remove pythonegg(3)(futures) from requires
- remove no need ls

* Wed Apr 20 2016 philippem <philippem> 5.0.1-1.mga6
+ Revision: 1003750
- imported package ipyparallel

